@@ -17,7 +17,8 @@ typedef struct {
   dword MDbuf[RMDsize/32];       /* contains (A, B, C, D, E)   */
   dword X[RIPEMD160_BLOCKSIZE/4]; /* current 16-word chunk      */
   dword count_lo, count_hi;      /* 64-bit byte count          */
-  dword local;                   /* unprocessed amount in data */
+  byte data[RIPEMD160_BLOCKSIZE]; /* unprocessed data */
+  dword local;                   /* amount of unprocessed data */
 } RIPEMD160_INFO;
 
 
